/* eslint-disable object-property-newline */
const chai = require('chai');
const clone = require('clone');
const chaiAsPromised = require('chai-as-promised');
const sinon = require('sinon');
const Data = require('./data/attandance-detection-utils-test.json');

const Utils = require('../utils');
const Constants = require('../constants');
const Handlers = require('../event_handlers');
const Api = require('../api');

chai.use(chaiAsPromised);
const { expect } = chai;

let Api_apiCreateSms;
let Api_apiCreateEmail;

describe('Utils.', () => {
    describe('isTkoFacilityOut.', () => {
        it('1. Do send on assign tag', () => {
            const prev = Data.isTkoFacilityOut.first.prev;
            const next = Data.isTkoFacilityOut.first.next;
            
            const result = Utils.isTkoFacilityOut(Utils.parseTrackable(prev.plist), Utils.parseTrackable(next.plist));
            expect(result).to.equal(false);
        });
        it('2. Do not send on unassign tag', () => {
            const prev = Data.isTkoFacilityOut.second.prev;
            const next = Data.isTkoFacilityOut.second.next;
    
            const result = Utils.isTkoFacilityOut(Utils.parseTrackable(prev.plist), Utils.parseTrackable(next.plist));
            expect(result).to.equal(false);
        });
    });
    
    describe('getSendingDestination.', () => {
        describe('Single subscriber with single notification', () => {
            it('1. Returns single phone+email', () => {
                const body = {
                    subscribers: {
                        'yXnnBpcXTYuy0Taex-GpQQ': {
                            name: 'ssdf',
                            addresses: { phone: '065666666666', email: 'lab+1@redpointpositioning.com' },
                            notifications: ['gdDv4_BFSAKeWTnRbr2SbA'],
                        },
                    },
                    notifications: {
                        gdDv4_BFSAKeWTnRbr2SbA: {
                            name: 'Facility_out_notifications',
                            conditions: { zone_severity_level: 1, alarm_type_list: [Constants.TRACKABLE_UNRESPONSIVE] },
                            active: 1,
                            types: { email: true, phone: true },
                            notificationType: 'ALARM',
                        },
                    },
                };
                const result = Utils.getSendingDestination(body.subscribers, body.notifications);
                const expected = {
                    phones: { '065666666666': '065666666666' },
                    emails: { 'lab+1@redpointpositioning.com': 'lab+1@redpointpositioning.com' },
                };
                expect(result).to.deep.equal(expected);
            });
            it('2. Returns single email 1', () => {
                const body = {
                    subscribers: {
                        'yXnnBpcXTYuy0Taex-GpQQ': {
                            name: 'ssdf',
                            addresses: { phone: '', email: 'lab+1@redpointpositioning.com' },
                            notifications: ['gdDv4_BFSAKeWTnRbr2SbA'],
                        },
                    },
                    notifications: {
                        gdDv4_BFSAKeWTnRbr2SbA: {
                            name: 'Facility_out_notifications',
                            conditions: { zone_severity_level: 1, alarm_type_list: [Constants.TRACKABLE_UNRESPONSIVE] },
                            active: 1,
                            types: { email: true, phone: true },
                            notificationType: 'ALARM',
                        },
                    },
                };
                const result = Utils.getSendingDestination(body.subscribers, body.notifications);
                const expected = {
                    emails: { 'lab+1@redpointpositioning.com': 'lab+1@redpointpositioning.com' },
                    phones: {},
                };
                expect(result).to.deep.equal(expected);
            });
            it('3. Returns single email 2', () => {
                const body = {
                    subscribers: {
                        'yXnnBpcXTYuy0Taex-GpQQ': {
                            name: 'ssdf',
                            addresses: { phone: '065666666666', email: 'lab+1@redpointpositioning.com' },
                            notifications: ['gdDv4_BFSAKeWTnRbr2SbA'],
                        },
                    },
                    notifications: {
                        gdDv4_BFSAKeWTnRbr2SbA: {
                            name: 'Facility_out_notifications',
                            conditions: { zone_severity_level: 1, alarm_type_list: [Constants.TRACKABLE_UNRESPONSIVE] },
                            active: 1,
                            types: { email: true, phone: false },
                            notificationType: 'ALARM',
                        },
                    },
                };
                const result = Utils.getSendingDestination(body.subscribers, body.notifications);
                const expected = {
                    emails: { 'lab+1@redpointpositioning.com': 'lab+1@redpointpositioning.com' },
                    phones: {},
                };
                expect(result).to.deep.equal(expected);
            });
            it('4. Returns single phone 1', () => {
                const body = {
                    subscribers: {
                        'yXnnBpcXTYuy0Taex-GpQQ': {
                            name: 'ssdf',
                            addresses: { phone: '065666666666', email: '' },
                            notifications: ['gdDv4_BFSAKeWTnRbr2SbA'],
                        },
                    },
                    notifications: {
                        gdDv4_BFSAKeWTnRbr2SbA: {
                            name: 'Facility_out_notifications',
                            conditions: { zone_severity_level: 1, alarm_type_list: [Constants.TRACKABLE_UNRESPONSIVE] },
                            active: 1,
                            types: { email: true, phone: true },
                            notificationType: 'ALARM',
                        },
                    },
                };
                const result = Utils.getSendingDestination(body.subscribers, body.notifications);
                const expected = {
                    phones: { '065666666666': '065666666666' },
                    emails: {},
                };
                expect(result).to.deep.equal(expected);
            });
            it('5. Returns single phone 2', () => {
                const body = {
                    subscribers: {
                        'yXnnBpcXTYuy0Taex-GpQQ': {
                            name: 'ssdf',
                            addresses: { phone: '065666666666', email: 'lab+1@redpointpositioning.com' },
                            notifications: ['gdDv4_BFSAKeWTnRbr2SbA'],
                        },
                    },
                    notifications: {
                        gdDv4_BFSAKeWTnRbr2SbA: {
                            name: 'Facility_out_notifications',
                            conditions: { zone_severity_level: 1, alarm_type_list: [Constants.TRACKABLE_UNRESPONSIVE] },
                            active: 1,
                            types: { email: false, phone: true },
                            notificationType: 'ALARM',
                        },
                    },
                };
                const result = Utils.getSendingDestination(body.subscribers, body.notifications);
                const expected = {
                    phones: { '065666666666': '065666666666' },
                    emails: {},
                };
                expect(result).to.deep.equal(expected);
            });
        });
        
        describe('Single subscriber no Constants.TRACKABLE_UNRESPONSIVE notification', () => {
            it('Returns empty', () => {
                const body = {
                    subscribers: {
                        'yXnnBpcXTYuy0Taex-GpQQ': {
                            name: 'ssdf',
                            addresses: { phone: '065666666666', email: 'lab+1@redpointpositioning.com' },
                            notifications: ['gdDv4_BFSAKeWTnRbr2SbA'],
                        },
                    },
                    notifications: {
                        gdDv4_BFSAKeWTnRbr2SbA: {
                            name: 'Facility_out_notifications',
                            conditions: { zone_severity_level: 1, alarm_type_list: ['low_battery_alarm'] },
                            active: 1,
                            types: { email: true, phone: true },
                            notificationType: 'ALARM',
                        },
                    },
                };
                const result = Utils.getSendingDestination(body.subscribers, body.notifications);
                const expected = {
                    phones: {},
                    emails: {},
                };
                expect(result).to.deep.equal(expected);
            });
        });
        
        describe('2 subscriber, 1 notification', () => {
            it('Returns single email 1', () => {
                const body = {
                    subscribers: {
                        'yXnnBpcXTYuy0Taex-GpQQ': {
                            name: 'ssdf',
                            addresses: { phone: '', email: 'lab+1@redpointpositioning.com' },
                            notifications: ['gdDv4_BFSAKeWTnRbr2SbA'],
                        },
                        'yXnnBpcXTYuy0Taex-GpQS': {
                            name: 'ssdf111',
                            addresses: { phone: '066315498674', email: '' },
                            notifications: ['gdDv4_BFSAKeWTnRbr2SbA'],
                        },
                    },
                    notifications: {
                        gdDv4_BFSAKeWTnRbr2SbA: {
                            name: 'Facility_out_notifications',
                            conditions: { zone_severity_level: 1, alarm_type_list: [Constants.TRACKABLE_UNRESPONSIVE] },
                            active: 1,
                            types: { email: true, phone: true },
                            notificationType: 'ALARM',
                        },
                    },
                };
                const result = Utils.getSendingDestination(body.subscribers, body.notifications);
                const expected = {
                    emails: { 'lab+1@redpointpositioning.com': 'lab+1@redpointpositioning.com' },
                    phones: { '066315498674': '066315498674' },
                };
                expect(result).to.deep.equal(expected);
            });
        });
        
        describe('1 subscriber, 2 notification', () => {
            it('Returns single email 1', () => {
                const body = {
                    subscribers: {
                        'yXnnBpcXTYuy0Taex-GpQQ': {
                            name: 'ssdf',
                            addresses: { phone: '066315498674', email: 'lab+1@redpointpositioning.com' },
                            notifications: ['gdDv4_BFSAKeWTnRbr2SbA', 'gdDv4_BFSAKeWTnRbr2Sb2'],
                        },
                    },
                    notifications: {
                        gdDv4_BFSAKeWTnRbr2SbA: {
                            name: 'Facility_out_notifications 1',
                            conditions: { zone_severity_level: 1, alarm_type_list: [Constants.TRACKABLE_UNRESPONSIVE] },
                            active: 1,
                            types: { email: true, phone: false },
                            notificationType: 'ALARM',
                        },
                        gdDv4_BFSAKeWTnRbr2Sb2: {
                            name: 'Facility_out_notifications 2',
                            conditions: { zone_severity_level: 1, alarm_type_list: [Constants.TRACKABLE_UNRESPONSIVE] },
                            active: 1,
                            types: { email: false, phone: true },
                            notificationType: 'ALARM',
                        },
                    },
                };
                const result = Utils.getSendingDestination(body.subscribers, body.notifications);
                const expected = {
                    emails: { 'lab+1@redpointpositioning.com': 'lab+1@redpointpositioning.com' },
                    phones: { '066315498674': '066315498674' },
                };
                expect(result).to.deep.equal(expected);
            });
            it('Returns single email and phone 1', () => {
                const body = {
                    subscribers: {
                        'yXnnBpcXTYuy0Taex-GpQQ': {
                            name: 'ssdf',
                            addresses: { phone: '066315498674', email: 'lab+1@redpointpositioning.com' },
                            notifications: ['gdDv4_BFSAKeWTnRbr2SbA', 'gdDv4_BFSAKeWTnRbr2Sb2'],
                        },
                    },
                    notifications: {
                        gdDv4_BFSAKeWTnRbr2SbA: {
                            name: 'Facility_out_notifications 1',
                            conditions: { zone_severity_level: 1, alarm_type_list: [Constants.TRACKABLE_UNRESPONSIVE] },
                            active: 1,
                            types: { email: true, phone: true },
                            notificationType: 'ALARM',
                        },
                        gdDv4_BFSAKeWTnRbr2Sb2: {
                            name: 'Facility_out_notifications 2',
                            conditions: { zone_severity_level: 1, alarm_type_list: [Constants.TRACKABLE_UNRESPONSIVE] },
                            active: 1,
                            types: { email: true, phone: true },
                            notificationType: 'ALARM',
                        },
                    },
                };
                const result = Utils.getSendingDestination(body.subscribers, body.notifications);
                const expected = {
                    phones: { '066315498674': '066315498674' },
                    emails: { 'lab+1@redpointpositioning.com': 'lab+1@redpointpositioning.com' },
                };
                expect(result).to.deep.equal(expected);
            });
            it('Returns single email and phone partial duplicate', () => {
                const body = {
                    subscribers: {
                        'yXnnBpcXTYuy0Taex-GpQQ': {
                            name: 'ssdf',
                            addresses: { phone: '066315498674', email: 'lab+1@redpointpositioning.com' },
                            notifications: ['gdDv4_BFSAKeWTnRbr2SbA', 'gdDv4_BFSAKeWTnRbr2Sb2'],
                        },
                    },
                    notifications: {
                        gdDv4_BFSAKeWTnRbr2SbA: {
                            name: 'Facility_out_notifications 1',
                            conditions: { zone_severity_level: 1, alarm_type_list: [Constants.TRACKABLE_UNRESPONSIVE] },
                            active: 1,
                            types: { email: true, phone: true },
                            notificationType: 'ALARM',
                        },
                        gdDv4_BFSAKeWTnRbr2Sb2: {
                            name: 'Facility_out_notifications 2',
                            conditions: { zone_severity_level: 1, alarm_type_list: [Constants.TRACKABLE_UNRESPONSIVE] },
                            active: 1,
                            types: { email: true, phone: false },
                            notificationType: 'ALARM',
                        },
                    },
                };
                const result = Utils.getSendingDestination(body.subscribers, body.notifications);
                const expected = {
                    phones: { '066315498674': '066315498674' },
                    emails: { 'lab+1@redpointpositioning.com': 'lab+1@redpointpositioning.com' },
                };
                expect(result).to.deep.equal(expected);
            });
            it('Returns not duplicate email and phone in different subscribers', () => {
                const body = {
                    subscribers: {
                        'yXnnBpcXTYuy0Taex-GpQQ': {
                            name: 'ssdf',
                            addresses: { phone: '066315498674', email: 'lab+1@redpointpositioning.com' },
                            notifications: ['gdDv4_BFSAKeWTnRbr2Sb2'],
                        },
                        'yXnnBpcXTYuy0Taex-GpQW': {
                            name: 'ssdf',
                            addresses: { phone: '0663154986', email: 'lab+1@redpointpositioning.com' },
                            notifications: ['gdDv4_BFSAKeWTnRbr2SbA'],
                        },
                    },
                    notifications: {
                        gdDv4_BFSAKeWTnRbr2SbA: {
                            name: 'Facility_out_notifications 1',
                            conditions: { zone_severity_level: 1, alarm_type_list: [Constants.TRACKABLE_UNRESPONSIVE] },
                            active: 1,
                            types: { email: true, phone: true },
                            notificationType: 'ALARM',
                        },
                        gdDv4_BFSAKeWTnRbr2Sb2: {
                            name: 'Facility_out_notifications 2',
                            conditions: { zone_severity_level: 1, alarm_type_list: [Constants.TRACKABLE_UNRESPONSIVE] },
                            active: 1,
                            types: { email: true, phone: true },
                            notificationType: 'ALARM',
                        },
                    },
                };
                const result = Utils.getSendingDestination(body.subscribers, body.notifications);
                const expected = {
                    phones: { '066315498674': '066315498674', '0663154986': '0663154986' },
                    emails: { 'lab+1@redpointpositioning.com': 'lab+1@redpointpositioning.com' },
                };
                expect(result).to.deep.equal(expected);
            });
        });
    });

    describe('Utils.', () => {
        const addonState = {
            trackables: {
                '1-w20IkMRumeVyd5UnpRKA': {
                    name: 'tko_1a', type: 'NAV', haveNode: true, responsive: false, category: 'PERSON',
                    sublocationUid: 'Ddfgfs45dg234hsfhDFADF', projectUid: 'gPrv4_BFSAKeWTnRbr2SbA',
                },
            },
            subscribers: {
                BLk32IQ1TMO7gBMMyLMmIA: {
                    name: 'subscribe', notifications: ['KOfVfOAsRveo14enGrPHDg'],
                    addresses: { phone: '+380682856439', email: 'dlukin+1@redpointpositioning.com' },
                    projectUid: 'gPrv4_BFSAKeWTnRbr2SbA',
                },
            },
            notifications: {
                KOfVfOAsRveo14enGrPHDg: {
                    name: 'notify', active: 1, types: { email: true, phone: false }, notificationType: 'ALARM',
                    conditions: { zone_severity_level: 2, alarm_type_list: [Constants.TRACKABLE_UNRESPONSIVE] },
                    projectUid: 'gPrv4_BFSAKeWTnRbr2SbA',
                },
                ZUqc00WnS6apNFkBDCLKiA: {
                    name: 'ssda', active: 0, types: { email: false, phone: true }, notificationType: 'ALARM',
                    conditions: { zone_severity_level: 1, alarm_type_list: ['zone_violation', Constants.TRACKABLE_UNRESPONSIVE] },
                    projectUid: 'gPrv4_BFSAKeWTnRbr2SbA',
                },
            },
            sublocations: {
                Ddfgfs45dg234hsfhDFADF: {
                    name: 'name',
                    projectUid: 'gPrv4_BFSAKeWTnRbr2SbA',
                },
            },
        };
        
        const MString = sinon.match.string;
        const state = new Handlers.AddonState(Utils.sendRecipients);
        function remakeUnresponsive() {
            state.trackableUpdateHandler({
                plist: {
                    uid: '1-w20IkMRumeVyd5UnpRKA', name: 'new trko', type: 'NAV', node: { responsive: true }, category: 'PERSON',
                    position: { sl_id: 'Ddfgfs45dg234hsfhDFADF' }, heartbeat: { sl_id: 'Ddfgfs45dg234hsfhDFADF' },
                    project_uid: 'gPrv4_BFSAKeWTnRbr2SbA',
                },
            });
            state.trackableUpdateHandler({
                plist: {
                    uid: '1-w20IkMRumeVyd5UnpRKA', name: 'new trko', type: 'NAV', node: { responsive: false }, category: 'PERSON',
                    position: { sl_id: 'Ddfgfs45dg234hsfhDFADF' }, heartbeat: { sl_id: 'Ddfgfs45dg234hsfhDFADF' },
                    project_uid: 'gPrv4_BFSAKeWTnRbr2SbA',
                },
            });
        }
        
        beforeEach(() => {
            state.testSetState(clone(addonState));
            Api_apiCreateSms = sinon.stub(Api, 'apiCreateSms');
            Api_apiCreateEmail = sinon.stub(Api, 'apiCreateEmail');
        });
        afterEach(() => {
            Api_apiCreateSms.restore();
            Api_apiCreateEmail.restore();
        });
    
        describe('No changes.', () => {
            it('make tko_1a responsive then unresponsive(switch responsive)', () => {
                remakeUnresponsive();
        
                expect(Api_apiCreateSms.callCount).to.equal(0);
                expect(Api_apiCreateEmail.callCount).to.equal(1);
        
                expect(Api_apiCreateEmail.withArgs(MString, 'dlukin+1@redpointpositioning.com', MString).callCount).to.equal(1);
            });
        });
        describe('Notifications changes.', () => {
            it('Update notification uid=ZUqc00WnS6apNFkBDCLKiA with active=1', () => {
                state.notificationCreatedUpdatedHandler({
                    plist: {
                        uid: 'ZUqc00WnS6apNFkBDCLKiA',
                        name: 'ssda', active: 1, types: { email: false, phone: true }, notificationType: 'ALARM',
                        conditions: { zone_severity_level: 1, alarm_type_list: ['zone_violation', Constants.TRACKABLE_UNRESPONSIVE] },
                    },
                });

                remakeUnresponsive();
        
                expect(Api_apiCreateSms.callCount).to.equal(0);
                expect(Api_apiCreateEmail.callCount).to.equal(1);
        
                expect(Api_apiCreateEmail.withArgs(MString, 'dlukin+1@redpointpositioning.com', MString).callCount).to.equal(1);
            });
            it('Update notification uid=KOfVfOAsRveo14enGrPHDg with alarm_type_list=[zone_violation]', () => {
                state.notificationCreatedUpdatedHandler({
                    plist: {
                        uid: 'KOfVfOAsRveo14enGrPHDg',
                        name: 'notify', active: 1, types: { email: true, phone: true }, notificationType: 'ALARM',
                        conditions: { zone_severity_level: 2, alarm_type_list: ['zone_violation'] },
                    },
                });
        
                remakeUnresponsive();
        
                expect(Api_apiCreateSms.callCount).to.equal(0);
                expect(Api_apiCreateEmail.callCount).to.equal(0);
            });
            it('Delete all notifications uid=KOfVfOAsRveo14enGrPHDg, uid=ZUqc00WnS6apNFkBDCLKiA', () => {
                state.notificationCreatedUpdatedHandler({
                    plist: { uid: 'KOfVfOAsRveo14enGrPHDg' },
                });
                state.notificationCreatedUpdatedHandler({
                    plist: { uid: 'ZUqc00WnS6apNFkBDCLKiA' },
                });
        
                remakeUnresponsive();
        
                expect(Api_apiCreateSms.callCount).to.equal(0);
                expect(Api_apiCreateEmail.callCount).to.equal(0);
            });
        });
        describe('Subscribers changes.', () => {
            it('Create subscribers BLk32IQ1TMO7gBMMyLMmI1 with new phone, same email, with notifications KOfVfOAsRveo14enGrPHDg', () => {
                state.subscriberCreatedUpdatedHandler({
                    plist: {
                        uid: 'BLk32IQ1TMO7gBMMyLMmI1',
                        name: 'subscribe2',
                        addresses: { phone: '+380682856436', email: 'dlukin+1@redpointpositioning.com' },
                        notifications: ['KOfVfOAsRveo14enGrPHDg'],
                    },
                });
        
                remakeUnresponsive();
        
                expect(Api_apiCreateSms.callCount).to.equal(0);
                expect(Api_apiCreateEmail.callCount).to.equal(1);
                expect(Api_apiCreateEmail.withArgs(MString, 'dlukin+1@redpointpositioning.com', MString).callCount).to.equal(1);
            });
            it('Create subscribers BLk32IQ1TMO7gBMMyLMmI2 with same phone, new email, with notifications KOfVfOAsRveo14enGrPHDg', () => {
                state.subscriberCreatedUpdatedHandler({
                    plist: {
                        uid: 'BLk32IQ1TMO7gBMMyLMmI2',
                        name: 'subscribe2',
                        addresses: { phone: '+380682856439', email: 'dlukin+2@redpointpositioning.com' },
                        notifications: ['KOfVfOAsRveo14enGrPHDg'],
                        project_uid: 'gPrv4_BFSAKeWTnRbr2SbA',
                    },
                });
        
                remakeUnresponsive();
        
                expect(Api_apiCreateSms.callCount).to.equal(0);
                expect(Api_apiCreateEmail.callCount).to.equal(2);
                expect(Api_apiCreateEmail.withArgs(MString, 'dlukin+1@redpointpositioning.com', MString).callCount).to.equal(1);
                expect(Api_apiCreateEmail.withArgs(MString, 'dlukin+2@redpointpositioning.com', MString).callCount).to.equal(1);
            });
            it('Delete all subscribers uid=BLk32IQ1TMO7gBMMyLMmIA', () => {
                state.subscriberDeletedHandler({
                    plist: { uid: 'BLk32IQ1TMO7gBMMyLMmIA' },
                });
        
                remakeUnresponsive();
        
                expect(Api_apiCreateSms.callCount).to.equal(0);
                expect(Api_apiCreateEmail.callCount).to.equal(0);
            });
        });
        describe('Subscribers/notifications changes.', () => {
            it('Create notification uid=ZUqc00WnS6apNFkBDCLKi1 and subscribe by uid=BLk32IQ1TMO7gBMMyLMmIA', () => {
                state.notificationCreatedUpdatedHandler({
                    plist: {
                        uid: 'ZUqc00WnS6apNFkBDCLKi1',
                        name: 'ssda', active: 1, types: { email: true, phone: true }, notificationType: 'ALARM',
                        conditions: { zone_severity_level: 1, alarm_type_list: [Constants.TRACKABLE_UNRESPONSIVE] },
                        project_uid: 'gPrv4_BFSAKeWTnRbr2SbA',
                    },
                });
    
                state.subscriberCreatedUpdatedHandler({
                    plist: {
                        uid: 'BLk32IQ1TMO7gBMMyLMmIA',
                        name: 'subscribe', notifications: ['KOfVfOAsRveo14enGrPHDg', 'ZUqc00WnS6apNFkBDCLKi1'],
                        addresses: { phone: '+380682856438', email: 'dlukin+2@redpointpositioning.com' },
                        project_uid: 'gPrv4_BFSAKeWTnRbr2SbA',
                    },
                });
    
                remakeUnresponsive();
    
                expect(Api_apiCreateSms.callCount).to.equal(1);
                expect(Api_apiCreateEmail.callCount).to.equal(1);
    
                expect(Api_apiCreateSms.withArgs(MString, '+380682856438').callCount).to.equal(1);
                expect(Api_apiCreateEmail.withArgs(MString, 'dlukin+2@redpointpositioning.com', MString).callCount).to.equal(1);
            });
            it('Create notification uid=ZUqc00WnS6apNFkBDCLKi1 and subscribe by new uid=QLk32IQ1TMO7gBMMyLMmIA', () => {
                state.notificationCreatedUpdatedHandler({
                    plist: {
                        uid: 'ZUqc00WnS6apNFkBDCLKi1',
                        name: 'ssda', active: 1, types: { email: true, phone: true }, notificationType: 'ALARM',
                        conditions: { zone_severity_level: 1, alarm_type_list: [Constants.TRACKABLE_UNRESPONSIVE] },
                        project_uid: 'gPrv4_BFSAKeWTnRbr2SbA',
                    },
                });
        
                state.subscriberCreatedUpdatedHandler({
                    plist: {
                        uid: 'QLk32IQ1TMO7gBMMyLMmIA',
                        name: 'subscribe1', notifications: ['KOfVfOAsRveo14enGrPHDg', 'ZUqc00WnS6apNFkBDCLKi1'],
                        addresses: { phone: '+380682856431', email: 'dlukin+0@redpointpositioning.com' },
                        project_uid: 'gPrv4_BFSAKeWTnRbr2SbA',
                    },
                });
        
                remakeUnresponsive();
        
                expect(Api_apiCreateSms.callCount).to.equal(1);
                expect(Api_apiCreateEmail.callCount).to.equal(2);
        
                expect(Api_apiCreateSms.withArgs(MString, '+380682856431').callCount).to.equal(1);
                expect(Api_apiCreateEmail.withArgs(MString, 'dlukin+1@redpointpositioning.com', MString).callCount).to.equal(1);
                expect(Api_apiCreateEmail.withArgs(MString, 'dlukin+0@redpointpositioning.com', MString).callCount).to.equal(1);
            });
        });
    });
});
