const http = require('http');
const logger = require('../../utils/logger');
const conf = require('../../routes/config');

function loadTrackablesApi() {
    const headers = {
        'X-User-Agent': 'Attendance detection addon',
        'Content-Type': 'application/json',
    };
    let completeData = '';
    return new Promise((resolve, reject) => {
        const req = http.request({
            method: 'GET',
            host: 'localhost',
            path: '/api/v2/private/trackable_objects',
            port: conf.API_GATEWAY_PORT || 8082,
            headers,
        }, (res) => {
            if (res.statusCode >= 400) {
                reject(new Error(`${res.statusCode}`));
            } else {
                res.setEncoding('utf8');
                res.on('data', (chunk) => {
                    completeData += chunk;
                });
                res.on('end', () => {
                    resolve(JSON.parse(completeData).trackableObjects);
                });
            }
        });
        req.on('error', (e) => {
            logger.logex(e);
            reject(e);
        });
        req.end();
    });
}
function loadNotificationsApi() {
    const headers = {
        'X-User-Agent': 'Attendance detection addon',
        'Content-Type': 'application/json',
    };
    let completeData = '';
    return new Promise((resolve, reject) => {
        const req = http.request({
            method: 'GET',
            host: 'localhost',
            path: '/api/v2/private/notifications',
            port: conf.API_GATEWAY_PORT || 8082,
            headers,
        }, (res) => {
            if (res.statusCode >= 400) {
                reject(new Error(`${res.statusCode}`));
            } else {    
                res.setEncoding('utf8');
                res.on('data', (chunk) => {
                    completeData += chunk;
                });
                res.on('end', () => {
                    resolve(JSON.parse(completeData).notifications);
                });
            }
        });
        req.on('error', (e) => {
            logger.logex(e);
            reject(e);
        });
        req.end();
    });
}
function loadSubscribersApi() {
    const headers = {
        'X-User-Agent': 'Attendance detection addon',
        'Content-Type': 'application/json',
    };
    let completeData = '';
    return new Promise((resolve, reject) => {
        const req = http.request({
            method: 'GET',
            host: 'localhost',
            path: '/api/v2/private/subscribers',
            port: conf.API_GATEWAY_PORT || 8082,
            headers,
        }, (res) => {
            if (res.statusCode >= 400) {
                reject(new Error(`${res.statusCode}`));
            } else {    
                res.setEncoding('utf8');
                res.on('data', (chunk) => {
                    completeData += chunk;
                });
                res.on('end', () => {
                    resolve(JSON.parse(completeData).subscribers);
                });
            }
        });
        req.on('error', (e) => {
            logger.logex(e);
            reject(e);
        });
        req.end();
    });
}
function loadSublocationsApi() {
    const headers = {
        'X-User-Agent': 'Attendance detection addon',
        'Content-Type': 'application/json',
    };
    let completeData = '';
    return new Promise((resolve, reject) => {
        const req = http.request({
            method: 'GET',
            host: 'localhost',
            path: '/api/v2/private/sublocations',
            port: conf.API_GATEWAY_PORT || 8082,
            headers,
        }, (res) => {
            if (res.statusCode >= 400) {
                reject(new Error(`${res.statusCode}`));
            } else {
                res.setEncoding('utf8');
                res.on('data', (chunk) => {
                    completeData += chunk;
                });
                res.on('end', () => {
                    resolve(JSON.parse(completeData).sublocations);
                });
            }
        });
        req.on('error', (e) => {
            logger.logex(e);
            reject(e);
        });
        req.end();
    });
}

async function loadTrackables() {
    return new Promise(async (resolve) => {
        try {
            const trackables = await loadTrackablesApi();
            resolve(trackables);
        } catch (e) {
            setTimeout(() => resolve(loadTrackables()), 5000);
        }
    });
}
async function loadNotifications() {
    return new Promise(async (resolve) => {
        try {
            const notifications = await loadNotificationsApi();
            resolve(notifications);
        } catch (e) {
            setTimeout(() => resolve(loadNotifications()), 5000);
        }
    });
}
async function loadSubscribers() {
    return new Promise(async (resolve) => {
        try {
            const subscribers = await loadSubscribersApi();
            resolve(subscribers);
        } catch (e) {
            setTimeout(() => resolve(loadSubscribers()), 5000);
        }
    });
}
async function loadSublocations() {
    return new Promise(async (resolve) => {
        try {
            const sublocations = await loadSublocationsApi();
            resolve(sublocations);
        } catch (e) {
            setTimeout(() => resolve(loadSublocations()), 5000);
        }
    });
}

async function apiCreateEmail(body, to, subject) {
    const postData = { body, to, subject };
    logger.verbose('[apiCreateEmail]: postData ', postData);
    const headers = {
        'X-User-Agent': 'Addon attendance detection',
        'Content-Type': 'application/json',
        'Content-Length': Buffer.byteLength(JSON.stringify(postData)),
    };
    
    const req = http.request({
        method: 'POST',
        host: 'localhost',
        path: '/api/v2/private/email',
        port: conf.API_GATEWAY_PORT || 8082,
        headers,
    }, (res) => {
        res.setEncoding('utf8');
        res.on('data', (chunk) => {
            logger.verbose(`node: ${chunk}`);
        });
        res.on('end', () => {
        
        });
    });
    req.on('error', (e) => {
        logger.logex(e);
    });
    // write data to request body
    req.write(JSON.stringify(postData));
    req.end();
}

async function apiCreateSms(text, to) {
    const postData = { text, to };
    logger.verbose('[apiCreateSms]: postData ', postData);
    const headers = {
        'X-User-Agent': 'Addon attendance detection',
        'Content-Type': 'application/json',
        'Content-Length': Buffer.byteLength(JSON.stringify(postData)),
    };
    
    const req = http.request({
        method: 'POST',
        host: 'localhost',
        path: '/api/v2/private/sms',
        port: conf.API_GATEWAY_PORT || 8082,
        headers,
    }, (res) => {
        res.setEncoding('utf8');
        res.on('data', (chunk) => {
            logger.verbose(`node: ${chunk}`);
        });
        res.on('end', () => {
        
        });
    });
    req.on('error', (e) => {
        logger.logex(e);
    });
    // write data to request body
    req.write(JSON.stringify(postData));
    req.end();
}

module.exports = {
    loadTrackables,
    loadNotifications,
    loadSubscribers,
    loadSublocations,
    apiCreateEmail,
    apiCreateSms,
};
