#!/usr/bin/env bash
set -x #echo on

_PROJECT="rtls-addons"
_VERSION=$( server/addons/attendance_detection/sys-services/rtls-get-version.sh )
_RELEASE=$( server/addons/attendance_detection/sys-services/rtls-get-release.sh )

CONTENT="Content-Type:application/json"

RPM_VERSION="${_VERSION}-${_RELEASE}"

echo 'PROJECT' ${_PROJECT}
echo '_VERSION' ${_VERSION}
echo '_RELEASE' ${_RELEASE}
echo 'RPM_VERSION' ${RPM_VERSION}

JIRA_TASKS_LIST=$(awk '/===/,/\#\#\ 20/&&++k==2' addons/CHANGELOG.md | grep DEV | cut -d "[" -f2 | cut -d "]" -f1)
echo "JIRA Tickets:"
echo "${JIRA_TASKS_LIST}"

CHANGELOG_VERSION="$(awk 'NR==3{print $2}' addons/CHANGELOG.md | sed 's/v//g' | sed 's/\[//g' | sed 's/\]//g')"
echo "Changelog version ${CHANGELOG_VERSION}"

COMMIT_VERSION="${_VERSION}"
if [[ "${CHANGELOG_VERSION}" =~ "-" ]]; then
  COMMIT_VERSION="${RPM_VERSION}"
fi

jira_add_comment() {
  DATA="{\"body\":\"The task has been released in the $_PROJECT-${RPM_VERSION} version\"}"

  for item in ${JIRA_TASKS_LIST}; do
    URL="https://redpointpositioning.atlassian.net/rest/api/2/issue/${item}/comment"
    echo "Running curl -D- -u ${JIRA_USER}:${JIRA_API_KEY} -X POST -H ${CONTENT} -d ${DATA} ${URL}"
    curl -D- -u "${JIRA_USER}:${JIRA_API_KEY}" -X POST -H "${CONTENT}" -d "${DATA}" "${URL}"
  done
}

jira_change_status() {
  DATA='{"transition":{"id":"481"}}'

  for item in ${JIRA_TASKS_LIST}; do
    URL="https://redpointpositioning.atlassian.net/rest/api/2/issue/${item}/transitions"
    echo "Running curl -D- -u ${JIRA_USER}:${JIRA_API_KEY} -X POST -H ${CONTENT} -d ${DATA} ${URL}"
    curl -D- -u "${JIRA_USER}:${JIRA_API_KEY}" -X POST -H "${CONTENT}" -d "${DATA}" "${URL}"
  done
}

if [ "${CHANGELOG_VERSION}" = "${COMMIT_VERSION}" ]; then
  jira_add_comment
  jira_change_status
else
  echo "FAIL! Your COMMIT_VERSION, is not equal to CHANGELOG_VERSION."
  echo " Please check that version in the changelog is correct"
  exit 1
fi
